@@ -1,6 +1,8 @@
 '''
 Utility functions.
 '''
+import os
+import sys
 import logging
 from pathlib import Path
 from collections.abc import MutableMapping
@@ -438,8 +440,9 @@ class ChainedAssignment:
             --code with errors--
     '''
     def __init__(self, chained=None):
-        acceptable = [None, 'warn', 'raise']
-        assert chained in acceptable, "chained must be in " + str(acceptable)
+        acceptable = [None, 'warn', 'raise', 'error']
+        if chained not in acceptable:
+            raise ValueError(f'`chained` must be one of {acceptable!r}, but input specifies {chained!r}.')
         self.swcw = chained
 
     def __enter__(self):
@@ -450,6 +453,27 @@ class ChainedAssignment:
     def __exit__(self, *args):
         pd.options.mode.chained_assignment = self.saved_swcw
 
+class HiddenPrints:
+    '''
+    Context manager to temporarily disable printing. Source: https://stackoverflow.com/a/45669280/17333120. Usage:
+        with HiddenPrints():
+            --code with no printing--
+        with HiddenPrints(False):
+            --code with printing--
+    '''
+    def __init__(self, hidden=True):
+        self.hidden = hidden
+
+    def __enter__(self):
+        if self.hidden:
+            self._original_stdout = sys.stdout
+            sys.stdout = open(os.devnull, 'w')
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        if self.hidden:
+            sys.stdout.close()
+            sys.stdout = self._original_stdout
+
 loggers = {}
 
 def logger_init(obj):
